/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* test-cdata.c
 *
 * Copyright (C) 2001 Paolo Casarini <paolo@casarini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

#include <glib.h>
#include <stdio.h>
#include <string.h>
#include <parser.h>
#include <gdome.h>
#include <gdome-xml-str.h>

void
dot() {
	printf(".");
	fflush(stdout);
}

gboolean
test_cdata1(GdomeDocument *doc) {
	GdomeText *txt, *txt1;
	GdomeException exc;
  GdomeDOMString *str;
  gboolean ret = TRUE;

	txt = doc->vtab->createTextNode (doc, gdome_xml_str_mkref("Initial String"), &exc);

  /* Test Text.length */
	if (txt->vtab->super.length ((GdomeCharacterData *)txt, &exc) != 14)
		fprintf (stderr, "\nText.length, wrong"), ret = FALSE;
  dot();

  /* Test Text.data */
	str = txt->vtab->super.data ((GdomeCharacterData *)txt, &exc);
  if (!xmlStrEqual(str->str, "Initial String"))
		fprintf (stderr, "\nText.data, wrong"), ret = FALSE;
  str->unref (str);
  dot();

	/* Test Text.set_data */
  str = gdome_xml_str_mkref ("0123456789");
	txt->vtab->super.set_data ((GdomeCharacterData *)txt, str, &exc);
	if (!xmlStrEqual(txt->vtab->super.data ((GdomeCharacterData *)txt, &exc)->str, "0123456789"))
		fprintf (stderr, "\nText.set_data, wrong"), ret = FALSE;
  str->unref (str);
  dot();

	/* Test Text.substringData() */
	str = txt->vtab->super.substringData ((GdomeCharacterData *)txt, 3L, 3L, &exc);
  if (!xmlStrEqual (str->str, "345"))
		fprintf (stderr, "\nText.substringData(3,3), wrong"), ret = FALSE;
  str->unref(str);
	str = txt->vtab->super.substringData ((GdomeCharacterData *)txt, 4L, 10L, &exc);
  if (!xmlStrEqual (str->str, "456789"))
		fprintf (stderr, "\nText.substringData(4,10), wrong"), ret = FALSE;
  str->unref(str);
	dot();

  /* Test Text.appendData() */
	str = gdome_xml_str_mkref ("ABCDEF");
  txt->vtab->super.appendData ((GdomeCharacterData *)txt, str, &exc);
	if (!xmlStrEqual(txt->vtab->super.data ((GdomeCharacterData *)txt, &exc)->str, "0123456789ABCDEF"))
		fprintf (stderr, "\nText.appendData, wrong"), ret = FALSE;
  str->unref(str);
	dot();

  /* Test Text.insertData() */
	str = gdome_xml_str_mkref ("X");
  txt->vtab->super.insertData ((GdomeCharacterData *)txt, 3L, str, &exc);
	if (!xmlStrEqual(txt->vtab->super.data ((GdomeCharacterData *)txt, &exc)->str, "012X3456789ABCDEF"))
		fprintf (stderr, "\nText.insertData, wrong"), ret = FALSE;
  str->unref(str);
	dot();

  /* Test Text.deleteData() */
  txt->vtab->super.deleteData ((GdomeCharacterData *)txt, 3L, 1L, &exc);
	if (!xmlStrEqual(txt->vtab->super.data ((GdomeCharacterData *)txt, &exc)->str, "0123456789ABCDEF"))
		fprintf (stderr, "\nText.deleteData(3,1), wrong"), ret = FALSE;
  txt->vtab->super.deleteData ((GdomeCharacterData *)txt, 10L, 8L, &exc);
	if (!xmlStrEqual(txt->vtab->super.data ((GdomeCharacterData *)txt, &exc)->str, "0123456789"))
		fprintf (stderr, "\nText.deleteData(10,8), wrong"), ret = FALSE;
	dot();

  /* Test Text.replaceData() */
	str = gdome_xml_str_mkref ("ABC");
  txt->vtab->super.replaceData ((GdomeCharacterData *)txt, 0L, 3L, str, &exc);
	if (!xmlStrEqual(txt->vtab->super.data ((GdomeCharacterData *)txt, &exc)->str, "ABC3456789"))
		fprintf (stderr, "\nText.replaceData(0,3,\"ABC\"), wrong"), ret = FALSE;
	str->unref(str);
	str = gdome_xml_str_mkref ("XXXXXX");
  txt->vtab->super.replaceData ((GdomeCharacterData *)txt, 4L, 3L, str, &exc);
	if (!xmlStrEqual(txt->vtab->super.data ((GdomeCharacterData *)txt, &exc)->str, "ABC3XXXXXX789"))
		fprintf (stderr, "\nText.replaceData(4,3,\"XXXXXX\"), wrong"), ret = FALSE;
	str->unref(str);
	str = gdome_xml_str_mkref ("XABCDEF");
  txt->vtab->super.replaceData ((GdomeCharacterData *)txt, 12L, 1L, str, &exc);
	if (!xmlStrEqual(txt->vtab->super.data ((GdomeCharacterData *)txt, &exc)->str, "ABC3XXXXXX78XABCDEF"))
		fprintf (stderr, "\nText.replaceData(12,1,\"XABCDEF\"), wrong"), ret = FALSE;
	str->unref(str);
	dot();

	printf ("test_cdata1\n");

	/* Test Text.splitText */
  txt1 = txt->vtab->splitText (txt, 10L, &exc);
	if (!xmlStrEqual(txt->vtab->super.data ((GdomeCharacterData *)txt, &exc)->str, "ABC3XXXXXX"))
		fprintf (stderr, "\nText.splitText(10), wrong"), ret = FALSE;
	if (!xmlStrEqual(txt1->vtab->super.data ((GdomeCharacterData *)txt1, &exc)->str, "78XABCDEF"))
		fprintf (stderr, "\nText1.splitText(10), wrong"), ret = FALSE;
  if (txt->vtab->super.super.nextSibling ((GdomeNode *)txt, &exc) != (GdomeNode *)txt1)
		fprintf (stderr, "\nText.splitText(10), wrong next"), ret = FALSE;
  if (txt1->vtab->super.super.previousSibling ((GdomeNode *)txt1, &exc) != (GdomeNode *)txt)
		fprintf (stderr, "\nText1.splitText(10), wrong previous"), ret = FALSE;
  dot();

	printf ("test_text1\n");

	return ret;
}

int
main (int argc, char **argv)
{
	GdomeDOMImplementation *domImpl = NULL;
	GdomeDocument *domdoc = NULL;
	GdomeDOMString *str = NULL;
	GdomeException exc = 0;
	gboolean ret;

	domImpl = gdome_DOMImplementation_mkref();
	str = gdome_xml_str_mkref ("TEST");
	domdoc = domImpl->vtab->createDocument (domImpl, NULL, str, NULL, &exc);

	ret = test_cdata1(domdoc);
  domImpl->vtab->freeDoc(domImpl, domdoc, &exc);

	if(ret)
		return 0;
	else
		return -1;
}
